.. _all-salt.runners:

==============
runner modules
==============

.. currentmodule:: salt.runners

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    asam
    auth
    cache
    cloud
    ddns
    doc
    drac
    error
    event
    f5
    fileserver
    git_pillar
    http
    jobs
    launchd
    lxc
    manage
    mine
    nacl
    network
    pagerduty
    pillar
    pkg
    queue
    reactor
    salt
    saltutil
    sdb
    smartos_vmadm
    search
    spacewalk
    ssh
    state
    survey
    test
    thin
    virt
    vistara
    winrepo
